@@ -72,7 +72,7 @@ class Chart(xmlwriter.XMLwriter):
         self.table = None
         self.title_formula = None
         self.title_name = None
-        self.cross_between = None
+        self.cross_between = 'between'
         self.default_marker = None
         self.series_gap = None
         self.series_overlap = None
@@ -564,6 +564,7 @@ class Chart(xmlwriter.XMLwriter):
             'major_unit_type': options.get('major_unit_type'),
             'log_base': options.get('log_base'),
             'crossing': options.get('crossing'),
+            'position_axis': options.get('position_axis'),
             'position': options.get('position'),
             'label_position': options.get('label_position'),
             'num_format': options.get('num_format'),
@@ -591,6 +592,17 @@ class Chart(xmlwriter.XMLwriter):
         if axis.get('position'):
             axis['position'] = axis['position'].lower()[0]
 
+        # Set the position for a category axis on or between the tick marks.
+        if axis.get('position_axis'):
+            if axis['position_axis'] == 'on_tick':
+                axis['position_axis'] = 'midCat'
+            elif axis['position_axis'] == 'between':
+               # Doesn't need to be modified.
+               pass
+            else:
+                # Otherwise use the default value.
+                axis['position_axis']
+
         # Set the font properties if present.
         axis['num_font'] = self._convert_font_args(options.get('num_font'))
         axis['name_font'] = self._convert_font_args(options.get('name_font'))
@@ -641,10 +653,16 @@ class Chart(xmlwriter.XMLwriter):
     def _process_names(self, name, name_formula):
         # Switch name and name_formula parameters if required.
 
-        # Name looks like a formula, use it to set name_formula.
-        if name is not None and re.match(r'^=?[^!]+!', name):
-            name_formula = name
-            name = ''
+        if name is not None:
+            if isinstance(name, list):
+                # Convert an list of values into a name formula.
+                cell = xl_rowcol_to_cell(name[1], name[2], True, True)
+                name_formula = name[0] + '!' + cell
+                name = ''
+            elif re.match(r'^=?[^!]+!', name):
+                # Name looks like a formula, use it to set name_formula.
+                name_formula = name
+                name = ''
 
         return name, name_formula
 
@@ -1590,7 +1608,7 @@ class Chart(xmlwriter.XMLwriter):
             self._write_c_crosses_at(x_axis.get('crossing'))
 
         # Write the c:crossBetween element.
-        self._write_cross_between()
+        self._write_cross_between(x_axis.get('position_axis'))
 
         # Write the c:majorUnit element.
         self._write_c_major_unit(y_axis.get('major_unit'))
@@ -1675,7 +1693,7 @@ class Chart(xmlwriter.XMLwriter):
             self._write_c_crosses_at(y_axis.get('crossing'))
 
         # Write the c:crossBetween element.
-        self._write_cross_between()
+        self._write_cross_between(y_axis.get('position_axis'))
 
         # Write the c:majorUnit element.
         self._write_c_major_unit(x_axis.get('major_unit'))
@@ -2009,12 +2027,10 @@ class Chart(xmlwriter.XMLwriter):
         else:
             self._xml_empty_tag('c:minorGridlines')
 
-    def _write_cross_between(self):
+    def _write_cross_between(self, val):
         # Write the <c:crossBetween> element.
-        val = self.cross_between
-
         if val is None:
-            val = 'between'
+            val = self.cross_between
 
         attributes = [('val', val)]
 
